XML: Basic Constructs
=====================

.. py:module:: pyslet.xml20081126.structures

This module defines classes for working with XML documents.  The version of the
standard implemented is the Extensible Markup Language (Fifth Edition), for more
info see: http://www.w3.org/TR/xml/

XML is an integral part of many standards for LET but Pyslet takes a slightly
different approach from the pre-existing XML support in the Python language. XML
elements are represented by instances of a basic :class:`Element` class which
can be used as a base class to customize document processing for specific types
of XML document.  It also allows these XML elements to 'come live' with
additional methods and behaviours.


Documents
---------

..	autoclass:: Node
	:members:
	:show-inheritance:
	
..	autoclass:: Document
	:members:
	:show-inheritance:

..	autofunction:: RegisterDocumentClass

Characters
~~~~~~~~~~

..	autofunction:: IsChar

..	autofunction:: IsDiscouraged


Common Syntactic Constructs
~~~~~~~~~~~~~~~~~~~~~~~~~~~

..	autofunction:: is_s

..	autofunction:: IsWhiteSpace

..	autofunction:: ContainsS

..	autofunction:: StripLeadingS

..	autofunction:: NormalizeSpace

..	autofunction:: CollapseSpace

..	autofunction:: IsNameStartChar

..	autofunction:: IsNameChar

..	autofunction:: IsValidName

..	autofunction:: IsReservedName

..	autofunction:: IsPubidChar


Character Data and Markup
~~~~~~~~~~~~~~~~~~~~~~~~~

..	autofunction:: EscapeCharData

..	autofunction:: EscapeCharData7


CDATA Sections
~~~~~~~~~~~~~~

..	autofunction:: EscapeCDSect


Prolog and Document Type Declaration
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

..	autoclass:: XMLDTD
	:members:
	:show-inheritance:

..	autoclass:: XMLDeclaration
	:members:
	:show-inheritance:


Logical Structures
------------------

..	autoclass:: Element
	:members:
	:show-inheritance:

..	autoclass:: ElementType
	:members:
	:show-inheritance:

..	autoclass:: XMLContentParticle
	:members:
	:show-inheritance:

..	autoclass:: XMLNameParticle
	:members:
	:show-inheritance:

..	autoclass:: XMLChoiceList
	:members:
	:show-inheritance:

..	autoclass:: XMLSequenceList
	:members:
	:show-inheritance:

..	autoclass:: XMLAttributeDefinition
	:members:
	:show-inheritance:
	


Physical Structures
-------------------

..	autoclass:: XMLEntity
	:members:
	:show-inheritance:

..	autoclass:: XMLGeneralEntity
	:members:
	:show-inheritance:

..	autoclass:: XMLParameterEntity
	:members:
	:show-inheritance:

..	autoclass:: XMLExternalID
	:members:
	:show-inheritance:

..	autoclass:: XMLTextDeclaration
	:members:
	:show-inheritance:
		
..	autoclass:: XMLNotation
	:members:
	:show-inheritance:


Character Classes
~~~~~~~~~~~~~~~~~


..	autofunction:: IsLetter

..	autofunction:: IsBaseChar

..	autofunction:: IsIdeographic

..	autofunction:: IsCombiningChar

..	autofunction:: is_digit

..	autofunction:: IsExtender



